Request

#[non_exhaustive]
pub enum Request<'a> { Destroy, CreateListener { listen_fd: BorrowedFd<'a>, close_fd: BorrowedFd<'a>, }, }

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Destroy

destroy the manager object

Destroy the manager. This doesn’t destroy objects created with the manager.

This is a destructor, once sent this object cannot be used any longer.



CreateListener

create a new security context

Creates a new security context with a socket listening FD.

The compositor will accept new client connections on listen_fd. listen_fd must be ready to accept new connections when this request is sent by the client. In other words, the client must call bind(2) and listen(2) before sending the FD.

close_fd is a FD that will signal hangup when the compositor should stop accepting new connections on listen_fd.

The compositor must continue to accept connections on listen_fd when the Wayland client which created the security context disconnects.

After sending this request, closing listen_fd and close_fd remains the only valid operation on them.

Fields

listen_fd: BorrowedFd<'a>

listening socket FD

close_fd: BorrowedFd<'a>

FD signaling when done

Implementations

Source

impl<'a> Request<'a>

pub fn opcode(&self) -> u16

Get the opcode number of this message